# Generated by Django 3.0.2 on 2020-02-09 04:42

from django.conf import settings
import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion
import easy_thumbnails.fields
import ink_cms.image


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='SiteSection',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, max_length=127, unique=True)),
            ],
            options={
                'verbose_name': 'Site Section',
                'verbose_name_plural': 'Site Sections',
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='Tag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, max_length=127, unique=True)),
            ],
            options={
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='UploadedImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_id', models.PositiveIntegerField()),
                ('image', easy_thumbnails.fields.ThumbnailerImageField(blank=True, null=True, upload_to=ink_cms.image.get_datestamped_upload_path)),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType')),
            ],
        ),
        migrations.CreateModel(
            name='Revision',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('data', django.contrib.postgres.fields.jsonb.JSONField()),
                ('date_created', models.DateTimeField(auto_now_add=True, db_index=True)),
                ('object_id', models.PositiveIntegerField()),
                ('action', models.CharField(choices=[('Edited', 'Edited'), ('Reverted', 'Reverted'), ('Published', 'Published'), ('Unpublished', 'Unpublished')], default='Edited', max_length=31)),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-date_created'],
                'index_together': {('content_type', 'object_id', 'date_created')},
            },
        ),
        migrations.CreateModel(
            name='Page',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('creation_date', models.DateTimeField(auto_now_add=True)),
                ('first_publication_date', models.DateTimeField(blank=True, null=True)),
                ('publication_date', models.DateTimeField(blank=True, db_index=True, null=True)),
                ('slug', models.CharField(db_index=True, max_length=255, unique=True)),
                ('title', models.CharField(max_length=511, unique=True)),
                ('workflowstate', models.CharField(choices=[('Draft', 'Draft'), ('Published', 'Published'), ('Modified', 'Published with later modifications')], db_index=True, default='Draft', max_length=15)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
                ('published_revision', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ink_cms.Revision')),
                ('site_section', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ink_cms.SiteSection')),
                ('tags', models.ManyToManyField(blank=True, to='ink_cms.Tag')),
            ],
            options={
                'verbose_name': 'Page',
                'verbose_name_plural': 'Pages',
                'ordering': ['-publication_date'],
            },
        ),
        migrations.CreateModel(
            name='BlogEntry',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('creation_date', models.DateTimeField(auto_now_add=True)),
                ('first_publication_date', models.DateTimeField(blank=True, null=True)),
                ('publication_date', models.DateTimeField(blank=True, db_index=True, null=True)),
                ('slug', models.CharField(db_index=True, max_length=255, unique=True)),
                ('title', models.CharField(max_length=511, unique=True)),
                ('workflowstate', models.CharField(choices=[('Draft', 'Draft'), ('Published', 'Published'), ('Modified', 'Published with later modifications')], db_index=True, default='Draft', max_length=15)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
                ('published_revision', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ink_cms.Revision')),
                ('site_section', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ink_cms.SiteSection')),
                ('tags', models.ManyToManyField(blank=True, to='ink_cms.Tag')),
            ],
            options={
                'verbose_name': 'Blog Entry',
                'verbose_name_plural': 'Blog Entries',
                'ordering': ['-publication_date'],
            },
        ),
        migrations.CreateModel(
            name='Article',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('creation_date', models.DateTimeField(auto_now_add=True)),
                ('first_publication_date', models.DateTimeField(blank=True, null=True)),
                ('publication_date', models.DateTimeField(blank=True, db_index=True, null=True)),
                ('slug', models.CharField(db_index=True, max_length=255, unique=True)),
                ('title', models.CharField(max_length=511, unique=True)),
                ('workflowstate', models.CharField(choices=[('Draft', 'Draft'), ('Published', 'Published'), ('Modified', 'Published with later modifications')], db_index=True, default='Draft', max_length=15)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
                ('published_revision', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ink_cms.Revision')),
                ('site_section', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ink_cms.SiteSection')),
                ('tags', models.ManyToManyField(blank=True, to='ink_cms.Tag')),
            ],
            options={
                'verbose_name': 'Article',
                'verbose_name_plural': 'Articles',
                'ordering': ['-publication_date'],
            },
        ),
    ]
